@@ -61,7 +61,7 @@ from tqdm import tqdm
 
 from deepcell_toolbox import erode_edges
 from deepcell_toolbox.compute_overlap import compute_overlap  # pylint: disable=E0401
-from deepcell_toolbox.compute_overlap_3D import compute_overlap_3D
+from deepcell_toolbox.compute_overlap import compute_overlap_3D
 
 
 def _cast_to_tuple(x):
@@ -986,8 +986,8 @@ class Metrics(object):
         slc = [slice(None)] * y_pred.ndim
         for i in range(n_features):
             slc[axis] = slice(i, i + 1)
-            yt = y_true[slc] > self.pixel_threshold
-            yp = y_pred[slc] > self.pixel_threshold
+            yt = y_true[tuple(slc)] > self.pixel_threshold
+            yp = y_pred[tuple(slc)] > self.pixel_threshold
             pm = PixelMetrics(yt, yp)
             pixel_metrics.append(pm.to_dict())
 
@@ -1146,8 +1146,8 @@ class Metrics(object):
             'n_true': n_true,
             'n_pred': n_pred,
             'recall': _round(recall),
-            'precision': _round(precision * 100),
-            'seg': _round(seg * 100),
+            'precision': _round(precision),
+            'seg': _round(seg),
             'jaccard': _round(jaccard),
             'total_errors': 0,
         }
